Learn R Programming

spectrino (version 2.0.0)

spnDelBlock: Delete a block from the current group of blocks

Description

Delete a block from the current group of blocks. You can delete all blocks <ALL> or the entire group <GROUP>. If you want to open a block, a group of blocks (even empty) must be present.

Usage

spnDelBlock(Block)

Arguments

Block

- character string of the name of the block to be deleted. -- <ALL> will delete all the block leaving empty group of blocks. -- <GROUP> will close current group of blocks leaving only the console behind.

Value

spnDelBlock returns TRUE if successful, FALSE - otherwise.

See Also

spnOpenBlock , spnOpenGroupOfBlocks , spnSaveBlock

Examples

Run this code
# NOT RUN {
# Initialization of Spectrino
spnNew() 

# generate test set
spnOpenGroupOfBlocks("<test>")

# delete a block
spnDelBlock("test2")

# Release of Spectrino
#spnFree(TRUE)
# }

Run the code above in your browser using DataLab