Learn R Programming

spectrino (version 2.0.0)

spnDelGrp: Delete a group(s) in the top tab/spec-tree

Description

Delete Grp group in the top tab/spec-tree. If Grp="*" or "<ALL>" then delete all of the groups from the spec-tree.

Usage

spnDelGrp(Grp)

Arguments

Grp

- the name(character string) or the index(integer) of the group; 0 - active group; "*" or "<ALL>" - all groups.

Value

spnDelGrp returns the number of groups after the deleting. (spnGetGrpCount)

See Also

spnDelSpc

Examples

Run this code
# NOT RUN {
# Initialization of Spectrino
spnNew() 

# generate test set
spnOpenTree("<test>")

# delete third group from the list
spnDelGrp(3)

# empty the whole list of groups
spnDelGrp("*") 

# Release of Spectrino
#spnFree(TRUE)
# }

Run the code above in your browser using DataLab