Learn R Programming

spectrino (version 2.0.0)

spnGetProperty: Get a property value from a block

Description

Get a property value from a block. The properties of a block can be configured from the block menu (configure).

Usage

spnGetProperty(Block, Prop)

Arguments

Block

- the name(character string) of a block.

Prop

- the name(character string) of a property. A special integrated property <ITERS> will give the current number of the iteration counter

Value

spnGetProperty returns the value of the property, the type depends of the type of propery in the block.

See Also

spnSetProperty

Examples

Run this code
# NOT RUN {
# Initialization of Spectrino
spnNew() 

# generate test set
spnOpenGroupOfBlocks("<test>")

# set a property
spnSetProperty("test1","objective.0",3.58)

# get a property
spnGetProperty("test1","objective.0") 

# Release of Spectrino
#spnFree(TRUE)
# }

Run the code above in your browser using DataLab