Learn R Programming

spectrino (version 2.0.0)

spnGetRefer: Get common X values in a vector of the active group in the top tab/spec-tree

Description

Get reference X set of values (vector). All the spectra in a group list are assumed to have common X set of values, so if there is loaded spectrum in different X values, the spectrum is recalculated to fit the set given by the options: Boundaries from Low to High by 1.

Usage

spnGetRefer()

Arguments

Value

spnGetRefer returns the reference X set of values (vector) of the active group in the top tab/spec-tree

See Also

spnGetSpc ,spnGetGrp , spnGetTree

Examples

Run this code
# NOT RUN {
# Initialization of Spectrino
spnNew() 

# generate test set
spnOpenTree("<test>")

# the reference X values
v1 <- spnGetRefer() 

# Release of Spectrino
#spnFree(TRUE)
# }

Run the code above in your browser using DataLab