Learn R Programming

spectrino (version 2.0.0)

spnGetSpc: Get the vector of specific spec in the top tab/spec-tree

Description

Get one spectrum (vector) - only the Y-values of raw (unprocessed) data. All the spectra in a group are assumed to have common X set of values, so if there is loaded spectrum in different X values, the spectrum is recalculated to fit that reference set. If Spc is * the command is equivalent to getGetGrp(False,Grp) and gives back preporocessed data.

Usage

spnGetSpc(Grp,Spc)

Arguments

Grp

- the name(character string) or the index(integer) of the spec-group; 0 - active group.

Spc

- the name(character string) or the index(integer) of spec; 0 - selected spec; "*" or "<ALL>" - all specs

Value

spnGetSpc returns one spectrum (vector) - only the Y-values of raw (unprocessed) data.

See Also

spnGetGrp , spnGetTree , spnGetRefer

Examples

Run this code
# NOT RUN {
# Initialization of Spectrino
spnNew() 

# generate test set
spnOpenTree("<test>")

# if "Test2" is the second group, and "test23" - the third spec in it
v1 <- spnGetSpc(2,3) 
# is equivalent to 
v1 <- spnGetSpc("Test2","test23")

# Release of Spectrino
#spnFree(TRUE)
# }

Run the code above in your browser using DataLab