Learn R Programming

spectrino (version 2.0.0)

spnGetSpcChecked: Gets the vector of the state of spec checking boxes of Grp group in the top tab/spec-tree

Description

Gets the logical vector of the state of checking boxes of Grp group.

Usage

spnGetSpcChecked(Grp)

Arguments

Grp

- the name(character string) or the index(integer) of the group; 0 - active group.

Value

spnGetSpcChecked returns the logical vector of checked spec state.

See Also

spnSetSpcChecked

Examples

Run this code
# NOT RUN {
# Initialization of Spectrino
spnNew() 

# generate test set
spnOpenTree("<test>")

# the logical vector of checked spec of the first group
bv1 <- spnGetSpcChecked(1) 

# Release of Spectrino
#spnFree(TRUE)
# }

Run the code above in your browser using DataLab