Learn R Programming

spectrino (version 2.0.0)

spnGetSpcCount: Number of spectra in Grp spec-group in the top tab/spec-tree

Description

Counts the number of specs in Grp group in the top tab/spec-tree.

Usage

spnGetSpcCount(OnlyChecked,Grp)

Arguments

OnlyChecked

- logical; if true gets only the checked specs

Grp

- the name(character string) or the index(integer) of the spec-group; 0 - active group.

Value

spnGetSpcCount returns number of specs in Grp group in the top tab/spec-tree.

See Also

spnGetGrpCount

Examples

Run this code
# NOT RUN {
# Initialization of Spectrino
spnNew() 

# generate test set
spnOpenTree("<test>")

# the number of the checked specs in second group
i1 <- spnGetSpcCount(TRUE,2) 

# the number of specs in the active group
i2 <- spnGetSpcCount(FALSE,0)

# the number of specs in "Test3" group
i3 <- spnGetSpcCount(FALSE,"Test3")

# Release of Spectrino
#spnFree(TRUE)
# }

Run the code above in your browser using DataLab