Learn R Programming

spectrino (version 2.0.0)

spnNew: Initialization of Spectrino

Description

Check if R-object of Spectrino exists, and if not, creates/initializes Spectrino object/application. The command recommendable, but optional - it will be called, when any command is executed, if the R-object of Spectrino does not exists.

Usage

spnNew(TimeOut = 2, Host = "127.0.0.1", Port = 9876)

Arguments

TimeOut

time to wait [s] for spectrino application to load and reply, default is 2. In case of time-out error maybe your hardware is not that fast and you may need to increase the TimeOut.

Host

Host IP address for the websocket server, the default is 127.0.0.1 which is localhost. Do not change it unless you really know what you are doing.

Port

Port of web-socket communication, default is 9876. Do not change it unless you really know what you are doing.

Value

spnNew - Gets back TRUE if the Spectrino object exists or has been created; otherwise - FALSE.

Examples

Run this code
# NOT RUN {
# Initialization of Spectrino
spnNew() 

# Release of Spectrino
#spnFree(TRUE)
# }

Run the code above in your browser using DataLab