spnSaveGroupOfBlocks: Save the current Group of Blocks
Description
Save the current group of blocks as a list of names. Depending of the option from option dialog the command will save (default) or not the block themselves.
If you want to make sure that the blocks are saved regardless that option use spnSaveBlock("<ALL>") after with this command. Blocks always are saved in the same directory of their group of blocks file.
Usage
spnSaveGroupOfBlocks(Filename = "")
Arguments
Filename
- character string. The extension (*.GBK) is not a must. All the filenames or directories must be with forward slashes e.g. D:/Spectrino/Blocks/Test.GBK. If the path is missing the default block path is assumed. If the argument Filename is missing, the filename when it was opened is assumed.
Value
spnSaverGroupOfBlocks returns TRUE if successful, FALSE - otherwise.
# NOT RUN {# Initialization of SpectrinospnNew()
# generate test setspnOpenGroupOfBlocks("<test>")
# save test groupspnSaveGroupOfBlocks("")
# Release of Spectrino#spnFree(TRUE)# }