Learn R Programming

spectrino (version 2.0.0)

spnSetProperty: Set a property value in a block

Description

Set a property value in a block. The properties of a block can be configured from the block menu (configure).

Usage

spnSetProperty(Block, Prop, Value)

Arguments

Block

- the name(character string) of a block.

Prop

- the name(character string) of a property.

Value

- the value of the property, the type depends of the type of property in the block.

Value

spnSetProperty returns TRUE if successful, FALSE - otherwise.

See Also

spnGetProperty

Examples

Run this code
# NOT RUN {
# Initialization of Spectrino
spnNew() 

# generate test set
spnOpenGroupOfBlocks("<test>")

# set a property
spnSetProperty("test1","objective.0",3.58)

# get a property
spnGetProperty("test1","objective.0") 

# Release of Spectrino
#spnFree(TRUE)
# }

Run the code above in your browser using DataLab