spnDelBlock: Delete a block from the current group of blocks
Description
Delete a block from the current group of blocks. You can delete all blocks <ALL> or the entire group <GROUP>. If you want to open a block, a group of blocks (even empty) must be present.
Usage
spnDelBlock(Block)
Arguments
Block
- character string of the name of the block to be deleted.
-- <ALL> will delete all the block leaving empty group of blocks.
-- <GROUP> will close current group of blocks leaving only the console behind.
Value
spnDelBlock returns TRUE if successful, FALSE - otherwise.
# NOT RUN {# Initialization of SpectrinospnNew()
# generate test setspnOpenGroupOfBlocks("<test>")
# delete a blockspnDelBlock("test2")
# Release of Spectrino#spnFree(TRUE)# }