spnGetRefer: Get common X values in a vector of the active group in the top tab/spec-tree
Description
Get reference X set of values (vector). All the spectra in a group list are assumed to have common X set of values, so if there is loaded spectrum in different X values, the spectrum is recalculated to fit the set given by the options: Boundaries from Low to High by 1.
Usage
spnGetRefer()
Arguments
Value
spnGetRefer returns the reference X set of values (vector) of the active group in the top tab/spec-tree
# NOT RUN {# Initialization of SpectrinospnNew()
# generate test setspnOpenTree("<test>")
# the reference X valuesv1 <- spnGetRefer()
# Release of Spectrino#spnFree(TRUE)# }