Control iteration count:
- if the expected number of iterations is unknown Initial should be set to -2 or -1 (without or with progres bar)
- if the expected number of iterations is known Initial should be set to that number
after initializing the iteration counter with any Initial<>0, your code should call Iteration() on each iteration (usually at the end)
Apart of the progress bar, the block will react to an iteration depending of how have been set. E.g. Chart will draw next value(s) and/or log will write next status according to the log template.