Spectrino validation - not conclusive, it tests only the most common functions and modes. If both Spec and Block are FALSE, it tests only the Spectrino object, connection and Spectrino app. presence.
Usage
spnValidation(Spec, Block)
Arguments
Spec
- logical (default is TRUE) option to include (or not) a test of most used spectral commands
Block
- logical (default is TRUE) option to include (or not) a test of most used block of prop. commands
Value
spnValidation - If it gets back "Validation confirmed" you have very good chances that Spectrino might work, otherwise you will have the error with a number (see the code).
# NOT RUN {# Initialization of Spectrino spnNew()
# test of the Spectrino object, connection and Spectrino app. presencespnValidation(FALSE,FALSE)
# Release of SpectrinospnFree(TRUE)
# }